@@ -5,28 +5,44 @@ package KeyboardNames;
 %models = (
     'A4Tech KB-21' => 'a4techKB21',
     'A4Tech KBS-8' => 'a4techKBS8',
+    'A4Tech Wireless Desktop RFKB-23' => 'a4_rfkb23',
     'ACPI Standard' => 'acpi',
     'Acer AirKey V' => 'airkey',
-    'Acer TravelMate 800' => 'acer_tm_800',
+    'Acer C300' => 'acer_c300',
+    'Acer Ferrari 4000' => 'acer_ferrari4k',
+    'Acer Laptop' => 'acer_laptop',
     'Advance Scorpius KI' => 'scorpius',
     'Amiga' => 'amiga',
+    'Apple' => 'apple',
+    'Apple Laptop' => 'apple_laptop',
+    'Asus Laptop' => 'asus_laptop',
     'Atari TT' => 'ataritt',
     'Azona RF2300 wireless Internet Keyboard' => 'azonaRF2300',
     'BTC 5090' => 'btc5090',
     'BTC 5113RF Multimedia' => 'btc5113rf',
     'BTC 5126T' => 'btc5126t',
+    'BTC 6301URF' => 'btc6301urf',
     'BTC 9000' => 'btc9000',
     'BTC 9000A' => 'btc9000a',
     'BTC 9001AH' => 'btc9001ah',
-    'Brazilian ABNT2' => 'abnt2',
+    'BTC 9019U' => 'btc9019u',
+    'BTC 9116U Mini Wireless Internet and Gaming' => 'btc9116u',
+    'BenQ X-Touch' => 'benqx',
+    'BenQ X-Touch 730' => 'benqx730',
+    'BenQ X-Touch 800' => 'benqx800',
     'Brother Internet Keyboard' => 'brother',
+    'Cherry B.UNLIMITED' => 'cherrybunlim',
     'Cherry Blue Line CyBo@rd' => 'cherryblue',
     'Cherry Blue Line CyBo@rd (alternate option)' => 'cherrybluea',
     'Cherry CyBo@rd USB-Hub' => 'cherrycyboard',
+    'Cherry CyMotion Expert' => 'cherrycmexpert',
     'Cherry CyMotion Master Linux' => 'cymotionlinux',
     'Cherry CyMotion Master XPress' => 'cherryblueb',
     'Chicony Internet Keyboard' => 'chicony',
     'Chicony KB-9885' => 'chicony9885',
+    'Chicony KU-0108' => 'chicony0108',
+    'Chicony KU-0420' => 'chicony0420',
+    'Classmate PC' => 'classmate',
     'Compaq Easy Access Keyboard' => 'compaqeak8',
     'Compaq Internet Keyboard (13 keys)' => 'compaqik13',
     'Compaq Internet Keyboard (18 keys)' => 'compaqik18',
@@ -35,11 +51,21 @@ package KeyboardNames;
     'DTK2000' => 'dtk2000',
     'Dell' => 'dell',
     'Dell 101-key PC' => 'dell101',
-    'Dell USB Multimedia Keybard' => 'dellusbmm',
+    'Dell Laptop/notebook Inspiron 6xxx/8xxx' => 'inspiron',
+    'Dell Laptop/notebook Precision M series' => 'precision_m',
+    'Dell Latitude series laptop' => 'latitude',
+    'Dell Precision M65' => 'dellm65',
+    'Dell SK-8125' => 'dellsk8125',
+    'Dell SK-8135' => 'dellsk8135',
+    'Dell USB Multimedia Keyboard' => 'dellusbmm',
     'Dexxa Wireless Desktop Keyboard' => 'dexxa',
     'Diamond 9801 / 9802 series' => 'diamond',
+    'Do not configure keyboard; keep kernel keymap' => 'SKIP',
     'Ennyah DKB-1008' => 'ennyah_dkb1008',
+    'Evdev-managed keyboard' => 'evdev',
     'Everex STEPnote' => 'everex',
+    'FL90' => 'compalfl90',
+    'Fujitsu-Siemens Computers AMILO laptop' => 'fscaa1667g',
     'Generic 101-key PC' => 'pc101',
     'Generic 102-key (Intl) PC' => 'pc102',
     'Generic 104-key PC' => 'pc104',
@@ -47,7 +73,11 @@ package KeyboardNames;
     'Genius Comfy KB-12e' => 'geniuscomfy',
     'Genius Comfy KB-16M / Genius MM Keyboard KWD-910' => 'genius',
     'Genius Comfy KB-21e-Scroll' => 'geniuscomfy2',
+    'Genius KB-19e NB' => 'geniuskb19e',
+    'Genius KKB-2050HS' => 'geniuskkb2050hs',
     'Gyration' => 'gyration',
+    'Happy Hacking Keyboard' => 'hhk',
+    'Happy Hacking Keyboard for Mac' => 'macintosh_hhk',
     'Hewlett-Packard Internet Keyboard' => 'hpi6',
     'Hewlett-Packard Omnibook 500 FA' => 'hp500fa',
     'Hewlett-Packard Omnibook 5xx' => 'hp5xx',
@@ -56,53 +86,67 @@ package KeyboardNames;
     'Hewlett-Packard Omnibook XE3 GF' => 'hpxe3gf',
     'Hewlett-Packard Omnibook XT1000' => 'hpxt1000',
     'Hewlett-Packard Pavilion ZT11xx' => 'hpzt11xx',
-    'Hewlett-Packard SK-2501 Multimedia Keyboard' => 'hp2501',
-    'Hewlett-Packard SK-2505 Internet Keyboard' => 'hp2505',
+    'Hewlett-Packard Pavilion dv5' => 'hpdv5',
+    'Hewlett-Packard SK-250x Multimedia Keyboard' => 'hp250x',
+    'Hewlett-Packard nx9020' => 'hpnx9020',
     'Honeywell Euroboard' => 'honeywell_euroboard',
     'IBM Rapid Access' => 'rapidaccess',
     'IBM Rapid Access II' => 'rapidaccess2',
-    'IBM Rapid Access II (alternate option)' => 'rapidaccess2a',
+    'IBM Space Saver' => 'ibm_spacesaver',
     'IBM ThinkPad 560Z/600/600E/A22E' => 'thinkpad',
-    'Japanese 106-key' => 'jp106',
+    'IBM ThinkPad 560Z/600/600E/A22E, Intl' => 'thinkpadintl',
+    'IBM ThinkPad R60/T60/R61/T61' => 'thinkpad60',
+    'IBM ThinkPad Z60m/Z60t/Z61m/Z61t' => 'thinkpadz60',
     'Keytronic FlexPro' => 'flexpro',
     'Laptop/notebook Compaq (eg. Armada) Laptop Keyboard' => 'armada',
     'Laptop/notebook Compaq (eg. Presario) Internet Keyboard' => 'presario',
-    'Laptop/notebook Dell Inspiron 6xxx/8xxx' => 'inspiron',
     'Laptop/notebook eMachines m68xx' => 'emachines',
     'Logitech Access Keyboard' => 'logiaccess',
-    'Logitech Cordless Desktop' => 'ltcd',
+    'Logitech Cordless Desktop' => 'logicd',
+    'Logitech Cordless Desktop (alternate option)' => 'logicda',
+    'Logitech Cordless Desktop EX110' => 'logiex110',
+    'Logitech Cordless Desktop LX-300' => 'logiclx300',
     'Logitech Cordless Desktop Navigator' => 'logicdn',
-    'Logitech Cordless Desktop Optical' => 'logicdo',
-    'Logitech Cordless Desktop Pro' => 'logicdp',
-    'Logitech Cordless Desktop Pro (alternate option)' => 'logicdpa',
-    'Logitech Cordless Desktop Pro (alternate option2)' => 'logicdpa2',
-    'Logitech Cordless Desktop iTouch' => 'logicdit',
+    'Logitech Cordless Desktop Optical' => 'logicd_opt',
+    'Logitech Cordless Desktop Pro (alternate option 2)' => 'logicdpa2',
+    'Logitech Cordless Desktop iTouch' => 'logicd_it',
     'Logitech Cordless Freedom/Desktop Navigator' => 'logicfn',
-    'Logitech Deluxe Access Keyboard' => 'logidak',
+    'Logitech G15 extra keys via G15daemon' => 'logitech_g15',
+    'Logitech Generic Keyboard' => 'logitech_base',
+    'Logitech Internet 350 Keyboard' => 'logii350',
     'Logitech Internet Keyboard' => 'logiik',
-    'Logitech Internet Navigator Keyboard' => 'logiink',
+    'Logitech Internet Navigator Keyboard' => 'logicink',
+    'Logitech Media Elite Keyboard' => 'logimel',
+    'Logitech Ultra-X Cordless Media Desktop Keyboard' => 'logiultraxc',
     'Logitech Ultra-X Keyboard' => 'logiultrax',
+    'Logitech diNovo Edge Keyboard' => 'logidinovoedge',
+    'Logitech diNovo Keyboard' => 'logidinovo',
     'Logitech iTouch' => 'itouch',
     'Logitech iTouch Cordless Keyboard (model Y-RB6)' => 'logiitc',
-    'Logitech iTouch keyboard Internet Navigator' => 'itouchin',
+    'Logitech iTouch Internet Navigator Keyboard SE' => 'logiinkse',
+    'Logitech iTouch Internet Navigator Keyboard SE (USB)' => 'logiinkseusb',
+    'MacBook/MacBook Pro' => 'macbook78',
+    'MacBook/MacBook Pro (Intl)' => 'macbook79',
     'Macintosh' => 'macintosh',
     'Macintosh Old' => 'macintosh_old',
     'Memorex MX1998' => 'mx1998',
     'Memorex MX2500 EZ-Access Keyboard' => 'mx2500',
     'Memorex MX2750' => 'mx2750',
+    'Microsoft Comfort Curve Keyboard 2000' => 'microsoftccurve2k',
     'Microsoft Internet Keyboard' => 'microsoftinet',
     'Microsoft Internet Keyboard Pro, Swedish' => 'microsoftprose',
     'Microsoft Natural' => 'microsoft',
+    'Microsoft Natural Keyboard Elite' => 'microsoftelite',
     'Microsoft Natural Keyboard Pro / Microsoft Internet Keyboard Pro' => 'microsoftpro',
     'Microsoft Natural Keyboard Pro OEM' => 'microsoftprooem',
     'Microsoft Natural Keyboard Pro USB / Microsoft Internet Keyboard Pro' => 'microsoftprousb',
+    'Microsoft Natural Wireless Ergonomic Keyboard 7000' => 'microsoft7000',
     'Microsoft Office Keyboard' => 'microsoftoffice',
     'Microsoft Wireless Multimedia Keyboard 1.0A' => 'microsoftmult',
     'Northgate OmniKey 101' => 'omnikey101',
-    'Oretec MCK-800 MM/Internet keyboard' => 'oretec',
+    'OLPC' => 'olpc',
+    'Ortek MCK-800 MM/Internet keyboard' => 'oretec',
     'PC-98xx Series' => 'pc98',
-    'Power G5' => 'power_g5',
-    'PowerPC PS/2' => 'powerpcps2',
     'Propeller Voyager (KTEZ-1000)' => 'propeller',
     'QTronix Scorpius 98N+' => 'qtronix',
     'SILVERCREST Multimedia Wireless Keyboard' => 'silvercrest',
@@ -111,15 +155,21 @@ package KeyboardNames;
     'SK-6200' => 'sk6200',
     'SK-7100' => 'sk7100',
     'SVEN Ergonomic 2500' => 'sven',
+    'SVEN Slim 303' => 'sven303',
     'Samsung SDM 4500P' => 'samsung4500',
     'Samsung SDM 4510P' => 'samsung4510',
     'Sun Type 4' => 'sun4',
     'Sun Type 5' => 'sun5',
+    'Sun Type 5/6' => 'sun6',
     'Super Power Multimedia Keyboard' => 'sp_inet',
     'Symplon PaceBook (tablet PC)' => 'symplon',
+    'Targa Visionary 811' => 'targa_v811',
     'Toshiba Satellite S3000' => 'toshiba_s3000',
     'Trust Direct Access Keyboard' => 'trustda',
+    'Trust Slimline' => 'trust_slimline',
     'Trust Wireless Keyboard Classic' => 'trust',
+    'Unitek KB-1925' => 'unitekkb1925',
+    'ViewSonic KU-306 Internet Keyboard' => 'vsonku306',
     'Winbook Model XP5' => 'winbook',
     'Yahoo! Internet Keyboard' => 'yahoo',
 );
@@ -136,15 +186,19 @@ package KeyboardNames;
     'Belgium' => 'be',
     'Bhutan' => 'bt',
     'Bosnia and Herzegovina' => 'ba',
+    'Braille' => 'brai',
     'Brazil' => 'br',
     'Bulgaria' => 'bg',
     'Cambodia' => 'kh',
     'Canada' => 'ca',
+    'China' => 'cn',
+    'Congo, Democratic Republic of the' => 'cd',
     'Croatia' => 'hr',
     'Czechia' => 'cz',
     'Denmark' => 'dk',
     'Esperanto' => 'epo',
     'Estonia' => 'ee',
+    'Ethiopia' => 'et',
     'Faroe Islands' => 'fo',
     'Finland' => 'fi',
     'France' => 'fr',
@@ -152,15 +206,19 @@ package KeyboardNames;
     'Germany' => 'de',
     'Ghana' => 'gh',
     'Greece' => 'gr',
+    'Guinea' => 'gn',
     'Hungary' => 'hu',
     'Iceland' => 'is',
     'India' => 'in',
     'Iran' => 'ir',
+    'Iraq' => 'iq',
     'Ireland' => 'ie',
     'Israel' => 'il',
     'Italy' => 'it',
     'Japan' => 'jp',
+    'Japan (PC-98xx Series)' => 'nec_vndr/jp',
     'Kazakhstan' => 'kz',
+    'Korea, Republic of' => 'kr',
     'Kyrgyzstan' => 'kg',
     'Laos' => 'la',
     'Latin American' => 'latam',
@@ -171,16 +229,20 @@ package KeyboardNames;
     'Malta' => 'mt',
     'Maori' => 'mao',
     'Mongolia' => 'mn',
+    'Montenegro' => 'me',
+    'Morocco' => 'ma',
     'Myanmar' => 'mm',
+    'Nepal' => 'np',
     'Netherlands' => 'nl',
+    'Nigeria' => 'ng',
     'Norway' => 'no',
-    'PC-98xx Series' => 'nec_vndr/jp',
     'Pakistan' => 'pk',
     'Poland' => 'pl',
     'Portugal' => 'pt',
     'Romania' => 'ro',
     'Russia' => 'ru',
-    'Serbia and Montenegro' => 'cs',
+    'Senegal' => 'sn',
+    'Serbia' => 'rs',
     'Slovakia' => 'sk',
     'Slovenia' => 'si',
     'South Africa' => 'za',
@@ -192,7 +254,8 @@ package KeyboardNames;
     'Tajikistan' => 'tj',
     'Thailand' => 'th',
     'Turkey' => 'tr',
-    'U.S. English' => 'us',
+    'Turkmenistan' => 'tm',
+    'USA' => 'us',
     'Ukraine' => 'ua',
     'United Kingdom' => 'gb',
     'Uzbekistan' => 'uz',
@@ -201,13 +264,21 @@ package KeyboardNames;
 
 %variants = (
     'af' => {
+	'OLPC Dari' => 'olpc-fa',
+	'OLPC Pashto' => 'olpc-ps',
+	'OLPC Southern Uzbek' => 'olpc-uz',
 	'Pashto' => 'ps',
 	'Southern Uzbek' => 'uz',
     },
     'am' => {
+	'Alternative Eastern' => 'eastern-alt',
+	'Alternative Phonetic' => 'phonetic-alt',
+	'Eastern' => 'eastern',
 	'Phonetic' => 'phonetic',
+	'Western' => 'western',
     },
     'ara' => {
+	'Buckwalter' => 'buckwalter',
 	'azerty' => 'azerty',
 	'azerty/digits' => 'azerty_digits',
 	'digits' => 'digits',
@@ -221,51 +292,65 @@ package KeyboardNames;
 	'US keyboard with Bosnian digraphs' => 'unicodeus',
 	'US keyboard with Bosnian letters' => 'us',
 	'Use Bosnian digraphs' => 'unicode',
-	'Use guillemots for quotes' => 'alternatequotes',
+	'Use guillemets for quotes' => 'alternatequotes',
     },
     'bd' => {
 	'Probhat' => 'probhat',
     },
     'be' => {
+	'Alternative' => 'oss',
+	'Alternative, Sun dead keys' => 'oss_sundeadkeys',
+	'Alternative, latin-9 only' => 'oss_latin9',
 	'Eliminate dead keys' => 'nodeadkeys',
 	'ISO Alternate' => 'iso-alternate',
 	'Sun dead keys' => 'sundeadkeys',
+	'Wang model 724 azerty' => 'wang',
     },
     'bg' => {
-	'Phonetic' => 'phonetic',
+	'Standard Phonetic' => 'bas_phonetic',
+	'Traditional Phonetic' => 'phonetic',
     },
     'br' => {
+	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Nativo' => 'nativo',
+	'Nativo for Esperanto' => 'nativo-epo',
+	'Nativo for USA keyboards' => 'nativo-us',
+    },
+    'brai' => {
+	'Left hand' => 'left_hand',
+	'Right hand' => 'right_hand',
     },
     'by' => {
 	'Latin' => 'latin',
 	'Winkeys' => 'winkeys',
     },
     'ca' => {
+	'English' => 'eng',
 	'French (legacy)' => 'fr-legacy',
 	'French Dvorak' => 'fr-dvorak',
 	'Inuktitut' => 'ike',
+	'Ktunaxa' => 'kut',
 	'Multilingual' => 'multix',
 	'Multilingual, first part' => 'multi',
 	'Multilingual, second part' => 'multi-2gr',
+	'Secwepemctsin' => 'shs',
     },
     'ch' => {
 	'French' => 'fr',
+	'French (Macintosh)' => 'fr_mac',
 	'French, Sun dead keys' => 'fr_sundeadkeys',
 	'French, eliminate dead keys' => 'fr_nodeadkeys',
+	'German (Macintosh)' => 'de_mac',
 	'German, Sun dead keys' => 'de_sundeadkeys',
 	'German, eliminate dead keys' => 'de_nodeadkeys',
     },
-    'cs' => {
-	'Latin' => 'latin',
-	'Latin Unicode' => 'latinunicode',
-	'Latin Unicode qwerty' => 'latinunicodeyz',
-	'Latin qwerty' => 'latinyz',
-	'Latin with guillemots' => 'latinalternatequotes',
-	'With guillemots' => 'alternatequotes',
-	'Z and ZHE swapped' => 'yz',
+    'cn' => {
+	'Tibetan' => 'tib',
+	'Tibetan (with ASCII numerals)' => 'tib_asciinum',
     },
     'cz' => {
+	'UCW layout (accented letters only)' => 'ucw',
 	'With <\|> key' => 'bksl',
 	'qwerty' => 'qwerty',
 	'qwerty, extended Backslash' => 'qwerty_bksl',
@@ -275,43 +360,78 @@ package KeyboardNames;
 	'Dead grave acute' => 'deadgraveacute',
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Lower Sorbian' => 'dsb',
+	'Lower Sorbian (qwertz)' => 'dsb_qwertz',
+	'Macintosh' => 'mac',
+	'Macintosh, eliminate dead keys' => 'mac_nodeadkeys',
+	'Neo 2' => 'neo',
 	'Romanian keyboard with German letters' => 'ro',
 	'Romanian keyboard with German letters, eliminate dead keys' => 'ro_nodeadkeys',
 	'Sun dead keys' => 'sundeadkeys',
+	'qwerty' => 'qwerty',
     },
     'dk' => {
+	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
+	'Macintosh, eliminate dead keys' => 'mac_nodeadkeys',
     },
     'ee' => {
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'US keyboard with Estonian letters' => 'us',
+    },
+    'epo' => {
+	'displaced semicolon and quote (obsolete)' => 'legacy',
     },
     'es' => {
+	'Asturian variant with bottom-dot H and bottom-dot L' => 'ast',
 	'Catalan variant with middle-dot L' => 'cat',
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Include dead tilde' => 'deadtilde',
+	'Macintosh' => 'mac',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'fi' => {
+	'Classic' => 'classic',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
 	'Northern Saami' => 'smi',
     },
     'fo' => {
 	'Eliminate dead keys' => 'nodeadkeys',
     },
     'fr' => {
-	'Alternative' => 'latin9',
-	'Alternative, Sun dead keys' => 'latin9_sundeadkeys',
-	'Alternative, eliminate dead keys' => 'latin9_nodeadkeys',
+	'(Legacy) Alternative' => 'latin9',
+	'(Legacy) Alternative, Sun dead keys' => 'latin9_sundeadkeys',
+	'(Legacy) Alternative, eliminate dead keys' => 'latin9_nodeadkeys',
+	'Alternative' => 'oss',
+	'Alternative, Sun dead keys' => 'oss_sundeadkeys',
+	'Alternative, eliminate dead keys' => 'oss_nodeadkeys',
+	'Alternative, latin-9 only' => 'oss_latin9',
+	'Bepo, ergonomic, Dvorak way' => 'bepo',
+	'Bepo, ergonomic, Dvorak way, latin-9 only' => 'bepo_latin9',
+	'Breton' => 'bre',
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Georgian AZERTY Tskapo' => 'geo',
+	'Macintosh' => 'mac',
+	'Occitan' => 'oci',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'gb' => {
+	'Colemak' => 'colemak',
 	'Dvorak' => 'dvorak',
+	'Dvorak (UK Punctuation)' => 'dvorakukp',
+	'Extended - Winkeys' => 'extd',
 	'International (with dead keys)' => 'intl',
+	'Macintosh' => 'mac',
     },
     'ge' => {
+	'Ergonomic' => 'ergonomic',
+	'MESS' => 'mess',
+	'Ossetian' => 'os',
 	'Russian' => 'ru',
     },
     'gh' => {
@@ -326,12 +446,13 @@ package KeyboardNames;
 	'Eliminate dead keys' => 'nodeadkeys',
 	'Extended' => 'extended',
 	'Polytonic' => 'polytonic',
+	'Simple' => 'simple',
     },
     'hr' => {
 	'US keyboard with Croatian digraphs' => 'unicodeus',
 	'US keyboard with Croatian letters' => 'us',
 	'Use Croatian digraphs' => 'unicode',
-	'Use guillemots for quotes' => 'alternatequotes',
+	'Use guillemets for quotes' => 'alternatequotes',
     },
     'hu' => {
 	'101/qwerty/comma/Dead keys' => '101_qwerty_comma_dead',
@@ -361,36 +482,66 @@ package KeyboardNames;
 	'UnicodeExpert' => 'UnicodeExpert',
     },
     'il' => {
+	'Biblical Hebrew (Tiro)' => 'biblical',
 	'Phonetic' => 'phonetic',
 	'lyx' => 'lyx',
-	'si1452' => 'si1452',
     },
     'in' => {
 	'Bengali' => 'ben',
 	'Bengali Probhat' => 'ben_probhat',
 	'Gujarati' => 'guj',
 	'Gurmukhi' => 'guru',
+	'Gurmukhi Jhelum' => 'jhelum',
+	'Hindi Bolnagri' => 'bolnagri',
+	'Hindi Wx' => 'hin-wx',
 	'Kannada' => 'kan',
 	'Malayalam' => 'mal',
+	'Malayalam Lalitha' => 'mal_lalitha',
 	'Oriya' => 'ori',
 	'Tamil' => 'tam',
 	'Tamil TAB Typewriter' => 'tam_TAB',
 	'Tamil TSCII Typewriter' => 'tam_TSCII',
 	'Tamil Unicode' => 'tam_unicode',
 	'Telugu' => 'tel',
-	'Urdu' => 'urd',
+	'Urdu, Alternative phonetic' => 'urd-phonetic3',
+	'Urdu, Phonetic' => 'urd-phonetic',
+	'Urdu, Winkeys' => 'urd-winkeys',
+    },
+    'iq' => {
+	'Kurdish, (F)' => 'ku_f',
+	'Kurdish, Arabic-Latin' => 'ku_ara',
+	'Kurdish, Latin Alt-Q' => 'ku_alt',
+	'Kurdish, Latin Q' => 'ku',
     },
     'ir' => {
 	'Keypad' => 'keypad',
+	'Kurdish, (F)' => 'ku_f',
+	'Kurdish, Arabic-Latin' => 'ku_ara',
+	'Kurdish, Latin Alt-Q' => 'ku_alt',
+	'Kurdish, Latin Q' => 'ku',
 	'Pro' => 'pro',
 	'Pro Keypad' => 'pro_keypad',
     },
     'is' => {
+	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
 	'Sun dead keys' => 'Sundeadkeys',
     },
     'it' => {
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Georgian' => 'geo',
+	'Macintosh' => 'mac',
+    },
+    'jp' => {
+	'Kana' => 'kana',
+	'OADG 109A' => 'OADG109A',
+    },
+    'kg' => {
+	'Phonetic' => 'phonetic',
+    },
+    'kr' => {
+	'101/104 key Compatible' => 'kr104',
     },
     'kz' => {
 	'Kazakh with Russian' => 'kazrus',
@@ -398,6 +549,7 @@ package KeyboardNames;
     },
     'latam' => {
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Include dead tilde' => 'deadtilde',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'lk' => {
@@ -405,6 +557,10 @@ package KeyboardNames;
 	'Tamil Unicode' => 'tam_unicode',
     },
     'lt' => {
+	'Baltic+' => 'balticplus',
+	'IBM (LST 1205-92)' => 'ibm',
+	'LEKP' => 'lekp',
+	'LEKPa' => 'lekpa',
 	'Standard' => 'std',
 	'US keyboard with Lithuanian letters' => 'us',
     },
@@ -413,53 +569,118 @@ package KeyboardNames;
 	'F-letter (F) variant' => 'fkey',
 	'Tilde (~) variant' => 'tilde',
     },
+    'ma' => {
+	'French' => 'french',
+	'Tifinagh' => 'tifinagh',
+	'Tifinagh Alternative' => 'tifinagh-alt',
+	'Tifinagh Alternative Phonetic' => 'tifinagh-alt-phonetic',
+	'Tifinagh Extended' => 'tifinagh-extended',
+	'Tifinagh Extended Phonetic' => 'tifinagh-extended-phonetic',
+	'Tifinagh Phonetic' => 'tifinagh-phonetic',
+    },
+    'me' => {
+	'Cyrillic' => 'cyrillic',
+	'Cyrillic with guillemets' => 'cyrillicalternatequotes',
+	'Cyrillic, Z and ZHE swapped' => 'cyrillicyz',
+	'Latin qwerty' => 'latinyz',
+	'Latin unicode' => 'latinunicode',
+	'Latin unicode qwerty' => 'latinunicodeyz',
+	'Latin with guillemets' => 'latinalternatequotes',
+    },
     'mk' => {
 	'Eliminate dead keys' => 'nodeadkeys',
     },
     'mt' => {
-	'US keyboard with Maltian letters' => 'us',
+	'Maltese keyboard with US layout' => 'us',
+    },
+    'ng' => {
+	'Hausa' => 'hausa',
+	'Igbo' => 'igbo',
+	'Yoruba' => 'yoruba',
     },
     'nl' => {
+	'Macintosh' => 'mac',
+	'Standard' => 'std',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'no' => {
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
+	'Macintosh, eliminate dead keys' => 'mac_nodeadkeys',
 	'Northern Saami' => 'smi',
 	'Northern Saami, eliminate dead keys' => 'smi_nodeadkeys',
     },
+    'pk' => {
+	'Arabic' => 'ara',
+	'CRULP' => 'urd-crulp',
+	'NLA' => 'urd-nla',
+    },
     'pl' => {
 	'Dvorak' => 'dvorak',
-	'Dvorak, Polish quotes on key "1/!"' => 'dvorak_altquotes',
+	'Dvorak, Polish quotes on key 1' => 'dvorak_altquotes',
 	'Dvorak, Polish quotes on quotemark key' => 'dvorak_quotes',
+	'Kashubian' => 'csb',
+	'Russian phonetic Dvorak' => 'ru_phonetic_dvorak',
 	'qwertz' => 'qwertz',
     },
     'pt' => {
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
+	'Macintosh, Sun dead keys' => 'mac_sundeadkeys',
+	'Macintosh, eliminate dead keys' => 'mac_nodeadkeys',
+	'Nativo' => 'nativo',
+	'Nativo for Esperanto' => 'nativo-epo',
+	'Nativo for USA keyboards' => 'nativo-us',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'ro' => {
+	'Cedilla' => 'cedilla',
+	'Crimean Tatar (Dobruca-1 Q)' => 'crh_dobruca1',
+	'Crimean Tatar (Dobruca-2 Q)' => 'crh_dobruca2',
+	'Crimean Tatar (Turkish Alt-Q)' => 'crh_alt',
+	'Crimean Tatar (Turkish F)' => 'crh_f',
 	'Standard' => 'std',
+	'Standard (Cedilla)' => 'std_cedilla',
 	'Winkeys' => 'winkeys',
     },
+    'rs' => {
+	'Latin' => 'latin',
+	'Latin Unicode' => 'latinunicode',
+	'Latin Unicode qwerty' => 'latinunicodeyz',
+	'Latin qwerty' => 'latinyz',
+	'Latin with guillemets' => 'latinalternatequotes',
+	'With guillemets' => 'alternatequotes',
+	'Z and ZHE swapped' => 'yz',
+    },
     'ru' => {
+	'Chuvash' => 'cv',
+	'Chuvash Latin' => 'cv_latin',
+	'DOS' => 'dos',
+	'Kalmyk' => 'xal',
+	'Komi' => 'kom',
+	'Legacy' => 'legacy',
+	'Ossetian, Winkeys' => 'os_winkeys',
+	'Ossetian, legacy' => 'os_legacy',
 	'Phonetic' => 'phonetic',
+	'Phonetic Winkeys' => 'phonetic_winkeys',
 	'Tatar' => 'tt',
 	'Typewriter' => 'typewriter',
-	'Winkeys' => 'winkeys',
+	'Udmurt' => 'udm',
+	'Yakut' => 'sah',
     },
     'se' => {
 	'Dvorak' => 'dvorak',
 	'Eliminate dead keys' => 'nodeadkeys',
+	'Macintosh' => 'mac',
 	'Northern Saami' => 'smi',
 	'Russian phonetic' => 'rus',
 	'Russian phonetic, eliminate dead keys' => 'rus_nodeadkeys',
+	'Svdvorak' => 'svdvorak',
     },
     'si' => {
-	'US keyboard with Slovenian digraphs' => 'unicodeus',
 	'US keyboard with Slovenian letters' => 'us',
-	'Use Slovenian digraphs' => 'unicode',
-	'Use guillemots for quotes' => 'alternatequotes',
+	'Use guillemets for quotes' => 'alternatequotes',
     },
     'sk' => {
 	'Extended Backslash' => 'bksl',
@@ -467,6 +688,9 @@ package KeyboardNames;
 	'qwerty, extended Backslash' => 'qwerty_bksl',
     },
     'sy' => {
+	'Kurdish, (F)' => 'ku_f',
+	'Kurdish, Latin Alt-Q' => 'ku_alt',
+	'Kurdish, Latin Q' => 'ku',
 	'Syriac' => 'syc',
 	'Syriac phonetic' => 'syc_phonetic',
     },
@@ -474,12 +698,30 @@ package KeyboardNames;
 	'Pattachote' => 'pat',
 	'TIS-820.2538' => 'tis',
     },
+    'tj' => {
+	'Legacy' => 'legacy',
+    },
+    'tm' => {
+	'Alt-Q' => 'alt',
+    },
     'tr' => {
 	'(F)' => 'f',
 	'Alt-Q' => 'alt',
+	'Crimean Tatar (Turkish Alt-Q)' => 'crh_alt',
+	'Crimean Tatar (Turkish F)' => 'crh_f',
+	'Crimean Tatar (Turkish Q)' => 'crh',
+	'International (with dead keys)' => 'intl',
+	'Kurdish, (F)' => 'ku_f',
+	'Kurdish, Latin Alt-Q' => 'ku_alt',
+	'Kurdish, Latin Q' => 'ku',
 	'Sun dead keys' => 'sundeadkeys',
     },
     'ua' => {
+	'Crimean Tatar (Turkish Alt-Q)' => 'crh_alt',
+	'Crimean Tatar (Turkish F)' => 'crh_f',
+	'Crimean Tatar (Turkish Q)' => 'crh',
+	'Homophonic' => 'homophonic',
+	'Legacy' => 'legacy',
 	'Phonetic' => 'phonetic',
 	'Standard RSTU' => 'rstu',
 	'Standard RSTU on Russian layout' => 'rstu_ru',
@@ -488,11 +730,26 @@ package KeyboardNames;
     },
     'us' => {
 	'Alternative international (former us_intl)' => 'alt-intl',
+	'Cherokee' => 'chr',
+	'Classic Dvorak' => 'dvorak-classic',
+	'Colemak' => 'colemak',
 	'Dvorak' => 'dvorak',
+	'Dvorak international' => 'dvorak-intl',
+	'Group toggle on multiply/divide key' => 'olpc2',
+	'International (AltGr dead keys)' => 'altgr-intl',
 	'International (with dead keys)' => 'intl',
 	'Left handed Dvorak' => 'dvorak-l',
+	'Macintosh' => 'mac',
+	'Programmer Dvorak' => 'dvp',
 	'Right handed Dvorak' => 'dvorak-r',
 	'Russian phonetic' => 'rus',
+	'With EuroSign on 5' => 'euro',
+    },
+    'uz' => {
+	'Crimean Tatar (Turkish Alt-Q)' => 'crh_alt',
+	'Crimean Tatar (Turkish F)' => 'crh_f',
+	'Crimean Tatar (Turkish Q)' => 'crh',
+	'Latin' => 'latin',
     },
 );
 
