@@ -1,7 +1,7 @@
 #! /usr/bin/python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8; Mode: Python; indent-tabs-mode: nil; tab-width: 4 -*-
 
-# Copyright (C) 2005, 2006 Canonical Ltd.
+# Copyright (C) 2005, 2006, 2007, 2008 Canonical Ltd.
 # Written by Colin Watson <cjwatson@ubuntu.com>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -42,14 +42,20 @@ DEBCONF_IO_OUT = 2
 DEBCONF_IO_ERR = 4
 DEBCONF_IO_HUP = 8
 
-class FilteredCommand(object):
-    def __init__(self, frontend, db=None):
-        self.frontend = frontend
-        # db does not normally need to be specified.
-        self.db = db
-        self.done = False
-        self.current_question = None
-        self.succeeded = False
+class UntrustedBase(object):
+    def get(self, attr):
+        '''Safely gets an attribute.  If it doesn't exist, returns None'''
+        if hasattr(self, attr):
+            return getattr(self, attr)
+        else:
+            return None
+
+    def call(self, method, *args, **kwargs):
+        '''Safely calls a member.  If it doesn't exist, returns None'''
+        if hasattr(self, method):
+            return getattr(self, method)(*args, **kwargs)
+        else:
+            return None
 
     @classmethod
     def debug_enabled(self):
@@ -65,11 +71,26 @@ class FilteredCommand(object):
             message = fmt % args
             print >>sys.stderr, '%s %s: %s' % (time_str, PACKAGE, message)
 
+class FilteredCommand(UntrustedBase):
+    def __init__(self, frontend, db=None, ui=None):
+        self.frontend = frontend # ubiquity-wide UI
+        self.ui = ui # page-specific UI
+        # db does not normally need to be specified.
+        self.db = db
+        self.done = False
+        self.current_question = None
+        self.succeeded = False
+        self.dbfilter = None
+
     def start(self, auto_process=False):
         self.status = None
         self.db = DebconfCommunicator(PACKAGE, cloexec=True)
+        self.ui_loop_level = 0
         prep = self.prepare()
-        self.command = ['log-output', '-t', 'ubiquity', '--pass-stdout']
+        if prep is None:
+            self.run(None, None)
+            return
+        self.command = ['log-output', '-t', PACKAGE, '--pass-stdout']
         if isinstance(prep[0], types.StringTypes):
             self.command.append(prep[0])
         else:
@@ -80,8 +101,6 @@ class FilteredCommand(object):
         else:
             env = {}
 
-        self.ui_loop_level = 0
-
         self.debug("Starting up '%s' for %s.%s", self.command,
                    self.__class__.__module__, self.__class__.__name__)
         self.debug("Watching for question patterns %s",
@@ -127,19 +146,19 @@ class FilteredCommand(object):
 
         self.cleanup()
 
-        self.db.shutdown()
-
         return ret
 
     def cleanup(self):
-        pass
+        self.db.shutdown()
 
     def run_command(self, auto_process=False):
         # TODO cjwatson 2006-02-25: Hack to allow _apply functions to be run
         # from within the debconffiltered Config class.
         if self.frontend is None:
             prep = self.prepare()
-            self.command = ['log-output', '-t', 'ubiquity', '--pass-stdout']
+            if prep is None:
+                return
+            self.command = ['log-output', '-t', PACKAGE, '--pass-stdout']
             if isinstance(prep[0], types.StringTypes):
                 self.command.append(prep[0])
             else:
@@ -177,6 +196,42 @@ class FilteredCommand(object):
             self.status = self.wait()
         return self.status
 
+    def run_unfiltered(self):
+        """This may only be called under the control of a debconf frontend."""
+
+        self.status = None
+
+        prep = self.prepare(unfiltered=True)
+        self.command = prep[0]
+        if len(prep) > 2:
+            env = prep[2]
+        else:
+            env = {}
+
+        self.debug("Starting up '%s' unfiltered for %s.%s", self.command,
+                   self.__class__.__module__, self.__class__.__name__)
+
+        def subprocess_setup():
+            os.environ['HOME'] = '/root'
+            os.environ['LC_COLLATE'] = 'C'
+            for key, value in env.iteritems():
+                os.environ[key] = value
+            # Python installs a SIGPIPE handler by default. This is bad for
+            # non-Python subprocesses, which need SIGPIPE set to the default
+            # action.
+            signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+
+        misc.regain_privileges()
+        ret = subprocess.call(self.command, preexec_fn=subprocess_setup)
+        misc.drop_privileges()
+        if ret != 0:
+            # TODO: error message if ret != 10
+            self.debug("%s exited with code %d", self.command, ret)
+
+        self.cleanup()
+
+        return ret
+
     def process_input(self, source, condition):
         if source != self.dbfilter.subout_fd:
             return True
@@ -323,6 +378,10 @@ class FilteredCommand(object):
         self.succeeded = True
         self.done = True
         self.exit_ui_loops()
+        if self.dbfilter is None:
+            # This is really a dummy dbfilter.  Let's exit for real now
+            self.frontend.debconffilter_done(self)
+            self.cleanup()
 
     # User selected Cancel, Back, or similar. Subclasses should override
     # this to send user-entered information back to debconf (perhaps using
@@ -333,6 +392,10 @@ class FilteredCommand(object):
         self.succeeded = False
         self.done = True
         self.exit_ui_loops()
+        if self.dbfilter is None:
+            # This is really a dummy dbfilter.  Let's exit for real now
+            self.frontend.debconffilter_done(self)
+            self.cleanup()
 
     def error(self, priority, question):
         self.succeeded = False
@@ -354,18 +417,17 @@ class FilteredCommand(object):
         self.current_question = question
         if not self.done:
             self.succeeded = False
-            n = self.__class__.__name__
-            self.frontend.set_page(n)
+            mod = __import__(self.__module__, fromlist=['NAME'])
+            self.frontend.set_page(mod.NAME)
             self.enter_ui_loop()
         return self.succeeded
 
     # Default progress bar handling: just pass it through to the frontend.
 
     def progress_start(self, progress_min, progress_max, progress_title):
-        ret = self.frontend.debconf_progress_start(
+        self.frontend.debconf_progress_start(
             progress_min, progress_max, self.description(progress_title))
         self.frontend.refresh()
-        return ret
 
     def progress_set(self, progress_title, progress_val):
         ret = self.frontend.debconf_progress_set(progress_val)
@@ -388,9 +450,8 @@ class FilteredCommand(object):
             return True
 
     def progress_stop(self, progress_title):
-        ret = self.frontend.debconf_progress_stop()
+        self.frontend.debconf_progress_stop()
         self.frontend.refresh()
-        return ret
 
     def progress_region(self, progress_title,
                         progress_region_start, progress_region_end):
